 ;////////////////////////////////////////////////////////////////////////////
 ;
 ;  Copyright (C) Microsoft Corporation.  All Rights Reserved.
 ;
 ;  File:       d3dx9tex.h
 ;  Content:    D3DX texturing APIs
 ;
 ;////////////////////////////////////////////////////////////////////////////
IFNDEF __D3DX9_H__
INCLUDE d3dx9.INC
ENDIF
IFNDEF __D3DX9TEX_H__
 ;----------------------------------------------------------------------------
 ; D3DX_FILTER flags:
 ; ------------------
 ;
 ; A valid filter must contain one of these values:
 ;
 ;  D3DX_FILTER_NONE
 ;      No scaling or filtering will take place.  Pixels outside the bounds
 ;      of the source image are assumed to be transparent black.
 ;  D3DX_FILTER_POINT
 ;      Each destination pixel is computed by sampling the nearest pixel
 ;      from the source image.
 ;  D3DX_FILTER_LINEAR
 ;      Each destination pixel is computed by linearly interpolating between
 ;      the nearest pixels in the source image.  This filter works best
 ;      when the scale on each axis is less than 2.
 ;  D3DX_FILTER_TRIANGLE
 ;      Every pixel in the source image contributes equally to the
 ;      destination image.  This is the slowest of all the filters.
 ;  D3DX_FILTER_BOX
 ;      Each pixel is computed by averaging a 2x2(x2) box pixels from
 ;      the source image. Only works when the dimensions of the
 ;      destination are half those of the source. (as with mip maps)
 ;
 ; And can be OR'd with any of these optional flags:
 ;
 ;  D3DX_FILTER_MIRROR_U
 ;      Indicates that pixels off the edge of the texture on the U-axis
 ;      should be mirrored, not wraped.
 ;  D3DX_FILTER_MIRROR_V
 ;      Indicates that pixels off the edge of the texture on the V-axis
 ;      should be mirrored, not wraped.
 ;  D3DX_FILTER_MIRROR_W
 ;      Indicates that pixels off the edge of the texture on the W-axis
 ;      should be mirrored, not wraped.
 ;  D3DX_FILTER_MIRROR
 ;      Same as specifying D3DX_FILTER_MIRROR_U | D3DX_FILTER_MIRROR_V |
 ;      D3DX_FILTER_MIRROR_V
 ;  D3DX_FILTER_DITHER
 ;      Dithers the resulting image using a 4x4 order dither pattern.
 ;  D3DX_FILTER_SRGB_IN
 ;      Denotes that the input data is in sRGB (gamma 2.2) colorspace.
 ;  D3DX_FILTER_SRGB_OUT
 ;      Denotes that the output data is in sRGB (gamma 2.2) colorspace.
 ;  D3DX_FILTER_SRGB
 ;      Same as specifying D3DX_FILTER_SRGB_IN | D3DX_FILTER_SRGB_OUT
 ;
 ;----------------------------------------------------------------------------
D3DX_FILTER_NONE	equ	<1 SHL  0>
D3DX_FILTER_POINT	equ	<2 SHL  0>
D3DX_FILTER_LINEAR	equ	<3 SHL  0>
D3DX_FILTER_TRIANGLE	equ	<4 SHL  0>
D3DX_FILTER_BOX	equ	<5 SHL  0>
D3DX_FILTER_MIRROR_U	equ	<1 SHL  16>
D3DX_FILTER_MIRROR_V	equ	<2 SHL  16>
D3DX_FILTER_MIRROR_W	equ	<4 SHL  16>
D3DX_FILTER_MIRROR	equ	<7 SHL  16>
D3DX_FILTER_DITHER	equ	<1 SHL  19>
D3DX_FILTER_SRGB_IN	equ	<1 SHL  20>
D3DX_FILTER_SRGB_OUT	equ	<2 SHL  20>
D3DX_FILTER_SRGB	equ	<3 SHL  20>
 ;----------------------------------------------------------------------------
 ; D3DX_NORMALMAP flags:
 ; ---------------------
 ; These flags are used to control how D3DXComputeNormalMap generates normal
 ; maps.  Any number of these flags may be OR'd together in any combination.
 ;
 ;  D3DX_NORMALMAP_MIRROR_U
 ;      Indicates that pixels off the edge of the texture on the U-axis
 ;      should be mirrored, not wraped.
 ;  D3DX_NORMALMAP_MIRROR_V
 ;      Indicates that pixels off the edge of the texture on the V-axis
 ;      should be mirrored, not wraped.
 ;  D3DX_NORMALMAP_MIRROR
 ;      Same as specifying D3DX_NORMALMAP_MIRROR_U | D3DX_NORMALMAP_MIRROR_V
 ;  D3DX_NORMALMAP_INVERTSIGN
 ;      Inverts the direction of each normal
 ;  D3DX_NORMALMAP_COMPUTE_OCCLUSION
 ;      Compute the per pixel Occlusion term and encodes it into the alpha.
 ;      An Alpha of 1 means that the pixel is not obscured in anyway, and
 ;      an alpha of 0 would mean that the pixel is completly obscured.
 ;
 ;----------------------------------------------------------------------------
 ;----------------------------------------------------------------------------
D3DX_NORMALMAP_MIRROR_U	equ	<1 SHL  16>
D3DX_NORMALMAP_MIRROR_V	equ	<2 SHL  16>
D3DX_NORMALMAP_MIRROR	equ	<3 SHL  16>
D3DX_NORMALMAP_INVERTSIGN	equ	<8 SHL  16>
D3DX_NORMALMAP_COMPUTE_OCCLUSION	equ	<16 SHL  16>
 ;----------------------------------------------------------------------------
 ; D3DX_CHANNEL flags:
 ; -------------------
 ; These flags are used by functions which operate on or more channels
 ; in a texture.
 ;
 ; D3DX_CHANNEL_RED
 ;     Indicates the red channel should be used
 ; D3DX_CHANNEL_BLUE
 ;     Indicates the blue channel should be used
 ; D3DX_CHANNEL_GREEN
 ;     Indicates the green channel should be used
 ; D3DX_CHANNEL_ALPHA
 ;     Indicates the alpha channel should be used
 ; D3DX_CHANNEL_LUMINANCE
 ;     Indicates the luminaces of the red green and blue channels should be
 ;     used.
 ;
 ;----------------------------------------------------------------------------
D3DX_CHANNEL_RED	equ	<1 SHL  0>
D3DX_CHANNEL_BLUE	equ	<1 SHL  1>
D3DX_CHANNEL_GREEN	equ	<1 SHL  2>
D3DX_CHANNEL_ALPHA	equ	<1 SHL  3>
D3DX_CHANNEL_LUMINANCE	equ	<1 SHL  4>
 ;----------------------------------------------------------------------------
 ; D3DXIMAGE_FILEFORMAT:
 ; ---------------------
 ; This enum is used to describe supported image file formats.
 ;
 ;----------------------------------------------------------------------------

;D3DXIMAGE_FILEFORMAT	UNION
	D3DXIFF_BMP	EQU 0 
	D3DXIFF_JPG	EQU 1 
	D3DXIFF_TGA	EQU 2 
	D3DXIFF_PNG	EQU 3 
	D3DXIFF_DDS	EQU 4 
	D3DXIFF_PPM	EQU 5 
	D3DXIFF_DIB	EQU 6 
	D3DXIFF_FORCE_DWORD	EQU 07fffffffh 
;D3DXIMAGE_FILEFORMAT		ENDS


 ;----------------------------------------------------------------------------
 ; LPD3DXFILL2D and LPD3DXFILL3D:
 ; ------------------------------
 ; Function types used by the texture fill functions.
 ;
 ; Parameters:
 ;  pOut
 ;      Pointer to a vector which the function uses to return its result.
 ;      X,Y,Z,W will be mapped to R,G,B,A respectivly.
 ;  pTexCoord
 ;      Pointer to a vector containing the coordinates of the texel currently
 ;      being evaluated.  Textures and VolumeTexture texcoord components
 ;      range from 0 to 1. CubeTexture texcoord component range from -1 to 1.
 ;  pTexelSize
 ;      Pointer to a vector containing the dimensions of the current texel.
 ;  pData
 ;      Pointer to user data.
 ;
 ;----------------------------------------------------------------------------
LPD3DXFILL2D PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
LPD3DXFILL3D PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXIMAGE_INFO:
 ; ---------------
 ; This structure is used to return a rough description of what the
 ; the original contents of an image file looked like.
 ;
 ;  Width
 ;      Width of original image in pixels
 ;  Height
 ;      Height of original image in pixels
 ;  Depth
 ;      Depth of original image in pixels
 ;  MipLevels
 ;      Number of mip levels in original image
 ;  Format
 ;      D3D format which most closely describes the data in original image
 ;  ResourceType
 ;      D3DRESOURCETYPE representing the type of texture stored in the file.
 ;      D3DRTYPE_TEXTURE, D3DRTYPE_VOLUMETEXTURE, or D3DRTYPE_CUBETEXTURE.
 ;  ImageFileFormat
 ;      D3DXIMAGE_FILEFORMAT representing the format of the image file.
 ;
 ;----------------------------------------------------------------------------

D3DXIMAGE_INFO	STRUCT
	Width1 DWORD ?
	Height DWORD ?
	Depth DWORD ?
	MipLevels DWORD ?
	Format DWORD ? 
	ResourceType DWORD ? 
	ImageFileFormat DWORD ?

D3DXIMAGE_INFO		ENDS

IFDEF __cplusplus
ENDIF  ;__cplusplus
 ;////////////////////////////////////////////////////////////////////////////
 ; Image File APIs ///////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; GetImageInfoFromFile/Resource:
 ; ------------------------------
 ; Fills in a D3DXIMAGE_INFO struct with information about an image file.
 ;
 ; Parameters:
 ;  pSrcFile
 ;      File name of the source image.
 ;  pSrcModule
 ;      Module where resource is located, or NULL for module associated
 ;      with image the os used to create the current process.
 ;  pSrcResource
 ;      Resource name
 ;  pSrcData
 ;      Pointer to file in memory.
 ;  SrcDataSize
 ;      Size in bytes of file in memory.
 ;  pSrcInfo
 ;      Pointer to a D3DXIMAGE_INFO structure to be filled in with the
 ;      description of the data in the source image file.
 ;
 ;----------------------------------------------------------------------------
;API
D3DXGetImageInfoFromFileA PROTO :DWORD ,:DWORD 
;API
D3DXGetImageInfoFromFileW PROTO :DWORD ,:DWORD 
IFDEF UNICODE
D3DXGetImageInfoFromFile	equ	<D3DXGetImageInfoFromFileW>
ELSE
D3DXGetImageInfoFromFile	equ	<D3DXGetImageInfoFromFileA>
ENDIF 
;API
D3DXGetImageInfoFromResourceA PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXGetImageInfoFromResourceW PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXGetImageInfoFromResource	equ	<D3DXGetImageInfoFromResourceW>
ELSE
D3DXGetImageInfoFromResource	equ	<D3DXGetImageInfoFromResourceA>
ENDIF 
;API
D3DXGetImageInfoFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD 
 ;////////////////////////////////////////////////////////////////////////////
 ; Load/Save Surface APIs ////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; D3DXLoadSurfaceFromFile/Resource:
 ; ---------------------------------
 ; Load surface from a file or resource
 ;
 ; Parameters:
 ;  pDestSurface
 ;      Destination surface, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestRect
 ;      Destination rectangle, or NULL for entire surface
 ;  pSrcFile
 ;      File name of the source image.
 ;  pSrcModule
 ;      Module where resource is located, or NULL for module associated
 ;      with image the os used to create the current process.
 ;  pSrcResource
 ;      Resource name
 ;  pSrcData
 ;      Pointer to file in memory.
 ;  SrcDataSize
 ;      Size in bytes of file in memory.
 ;  pSrcRect
 ;      Source rectangle, or NULL for entire image
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;  pSrcInfo
 ;      Pointer to a D3DXIMAGE_INFO structure to be filled in with the
 ;      description of the data in the source image file, or NULL.
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadSurfaceFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXLoadSurfaceFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXLoadSurfaceFromFile	equ	<D3DXLoadSurfaceFromFileW>
ELSE
D3DXLoadSurfaceFromFile	equ	<D3DXLoadSurfaceFromFileA>
ENDIF 
;API
D3DXLoadSurfaceFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXLoadSurfaceFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXLoadSurfaceFromResource	equ	<D3DXLoadSurfaceFromResourceW>
ELSE
D3DXLoadSurfaceFromResource	equ	<D3DXLoadSurfaceFromResourceA>
ENDIF 
;API
D3DXLoadSurfaceFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXLoadSurfaceFromSurface:
 ; ---------------------------
 ; Load surface from another surface (with color conversion)
 ;
 ; Parameters:
 ;  pDestSurface
 ;      Destination surface, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestRect
 ;      Destination rectangle, or NULL for entire surface
 ;  pSrcSurface
 ;      Source surface
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcRect
 ;      Source rectangle, or NULL for entire surface
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadSurfaceFromSurface PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXLoadSurfaceFromMemory:
 ; --------------------------
 ; Load surface from memory.
 ;
 ; Parameters:
 ;  pDestSurface
 ;      Destination surface, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestRect
 ;      Destination rectangle, or NULL for entire surface
 ;  pSrcMemory
 ;      Pointer to the top-left corner of the source image in memory
 ;  SrcFormat
 ;      Pixel format of the source image.
 ;  SrcPitch
 ;      Pitch of source image, in bytes.  For DXT formats, this number
 ;      should represent the width of one row of cells, in bytes.
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcRect
 ;      Source rectangle.
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadSurfaceFromMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXSaveSurfaceToFile:
 ; ----------------------
 ; Save a surface to a image file.
 ;
 ; Parameters:
 ;  pDestFile
 ;      File name of the destination file
 ;  DestFormat
 ;      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
 ;  pSrcSurface
 ;      Source surface, containing the image to be saved
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcRect
 ;      Source rectangle, or NULL for the entire image
 ;
 ;----------------------------------------------------------------------------
;API
D3DXSaveSurfaceToFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXSaveSurfaceToFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXSaveSurfaceToFile	equ	<D3DXSaveSurfaceToFileW>
ELSE
D3DXSaveSurfaceToFile	equ	<D3DXSaveSurfaceToFileA>
ENDIF 
 ;////////////////////////////////////////////////////////////////////////////
 ; Load/Save Volume APIs /////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; D3DXLoadVolumeFromFile/Resource:
 ; --------------------------------
 ; Load volume from a file or resource
 ;
 ; Parameters:
 ;  pDestVolume
 ;      Destination volume, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestBox
 ;      Destination box, or NULL for entire volume
 ;  pSrcFile
 ;      File name of the source image.
 ;  pSrcModule
 ;      Module where resource is located, or NULL for module associated
 ;      with image the os used to create the current process.
 ;  pSrcResource
 ;      Resource name
 ;  pSrcData
 ;      Pointer to file in memory.
 ;  SrcDataSize
 ;      Size in bytes of file in memory.
 ;  pSrcBox
 ;      Source box, or NULL for entire image
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;  pSrcInfo
 ;      Pointer to a D3DXIMAGE_INFO structure to be filled in with the
 ;      description of the data in the source image file, or NULL.
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadVolumeFromFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXLoadVolumeFromFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXLoadVolumeFromFile	equ	<D3DXLoadVolumeFromFileW>
ELSE
D3DXLoadVolumeFromFile	equ	<D3DXLoadVolumeFromFileA>
ENDIF 
;API
D3DXLoadVolumeFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXLoadVolumeFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXLoadVolumeFromResource	equ	<D3DXLoadVolumeFromResourceW>
ELSE
D3DXLoadVolumeFromResource	equ	<D3DXLoadVolumeFromResourceA>
ENDIF 
;API
D3DXLoadVolumeFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXLoadVolumeFromVolume:
 ; -------------------------
 ; Load volume from another volume (with color conversion)
 ;
 ; Parameters:
 ;  pDestVolume
 ;      Destination volume, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestBox
 ;      Destination box, or NULL for entire volume
 ;  pSrcVolume
 ;      Source volume
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcBox
 ;      Source box, or NULL for entire volume
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadVolumeFromVolume PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXLoadVolumeFromMemory:
 ; -------------------------
 ; Load volume from memory.
 ;
 ; Parameters:
 ;  pDestVolume
 ;      Destination volume, which will receive the image.
 ;  pDestPalette
 ;      Destination palette of 256 colors, or NULL
 ;  pDestBox
 ;      Destination box, or NULL for entire volume
 ;  pSrcMemory
 ;      Pointer to the top-left corner of the source volume in memory
 ;  SrcFormat
 ;      Pixel format of the source volume.
 ;  SrcRowPitch
 ;      Pitch of source image, in bytes.  For DXT formats, this number
 ;      should represent the size of one row of cells, in bytes.
 ;  SrcSlicePitch
 ;      Pitch of source image, in bytes.  For DXT formats, this number
 ;      should represent the size of one slice of cells, in bytes.
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcBox
 ;      Source box.
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;
 ;----------------------------------------------------------------------------
;API
D3DXLoadVolumeFromMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXSaveVolumeToFile:
 ; ---------------------
 ; Save a volume to a image file.
 ;
 ; Parameters:
 ;  pDestFile
 ;      File name of the destination file
 ;  DestFormat
 ;      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
 ;  pSrcVolume
 ;      Source volume, containing the image to be saved
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  pSrcBox
 ;      Source box, or NULL for the entire volume
 ;
 ;----------------------------------------------------------------------------
;API
D3DXSaveVolumeToFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXSaveVolumeToFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXSaveVolumeToFile	equ	<D3DXSaveVolumeToFileW>
ELSE
D3DXSaveVolumeToFile	equ	<D3DXSaveVolumeToFileA>
ENDIF 
 ;////////////////////////////////////////////////////////////////////////////
 ; Create/Save Texture APIs //////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; D3DXCheckTextureRequirements:
 ; -----------------------------
 ; Checks texture creation parameters.  If parameters are invalid, this
 ; function returns corrected parameters.
 ;
 ; Parameters:
 ;
 ;  pDevice
 ;      The D3D device to be used
 ;  pWidth, pHeight, pDepth, pSize
 ;      Desired size in pixels, or NULL.  Returns corrected size.
 ;  pNumMipLevels
 ;      Number of desired mipmap levels, or NULL.  Returns corrected number.
 ;  Usage
 ;      Texture usage flags
 ;  pFormat
 ;      Desired pixel format, or NULL.  Returns corrected format.
 ;  Pool
 ;      Memory pool to be used to create texture
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCheckTextureRequirements PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCheckCubeTextureRequirements PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCheckVolumeTextureRequirements PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateTexture:
 ; ------------------
 ; Create an empty texture
 ;
 ; Parameters:
 ;
 ;  pDevice
 ;      The D3D device with which the texture is going to be used.
 ;  Width, Height, Depth, Size
 ;      size in pixels. these must be non-zero
 ;  MipLevels
 ;      number of mip levels desired. if zero or D3DX_DEFAULT, a complete
 ;      mipmap chain will be created.
 ;  Usage
 ;      Texture usage flags
 ;  Format
 ;      Pixel format.
 ;  Pool
 ;      Memory pool to be used to create texture
 ;  ppTexture, ppCubeTexture, ppVolumeTexture
 ;      The texture object that will be created
 ;
 ;----------------------------------------------------------------------------
;API
D3DXCreateTexture PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTexture PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTexture PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXCreateTextureFromFile/Resource:
 ; -----------------------------------
 ; Create a texture object from a file or resource.
 ;
 ; Parameters:
 ;
 ;  pDevice
 ;      The D3D device with which the texture is going to be used.
 ;  pSrcFile
 ;      File name.
 ;  hSrcModule
 ;      Module handle. if NULL, current module will be used.
 ;  pSrcResource
 ;      Resource name in module
 ;  pvSrcData
 ;      Pointer to file in memory.
 ;  SrcDataSize
 ;      Size in bytes of file in memory.
 ;  Width, Height, Depth, Size
 ;      Size in pixels.  If zero or D3DX_DEFAULT, the size will be taken from
 ;      the file and rounded up to a power of two.  If D3DX_DEFAULT_NONPOW2,
 ;      the size will be not be rounded, if the device supports NONPOW2 textures.
 ;  MipLevels
 ;      Number of mip levels.  If zero or D3DX_DEFAULT, a complete mipmap
 ;      chain will be created.
 ;  Usage
 ;      Texture usage flags
 ;  Format
 ;      Desired pixel format.  If D3DFMT_UNKNOWN, the format will be
 ;      taken from the file.
 ;  Pool
 ;      Memory pool to be used to create texture
 ;  Filter
 ;      D3DX_FILTER flags controlling how the image is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_TRIANGLE.
 ;  MipFilter
 ;      D3DX_FILTER flags controlling how each miplevel is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_BOX,
 ;  ColorKey
 ;      Color to replace with transparent black, or 0 to disable colorkey.
 ;      This is always a 32-bit ARGB color, independent of the source image
 ;      format.  Alpha is significant, and should usually be set to FF for
 ;      opaque colorkeys.  (ex. Opaque black == 0xff000000)
 ;  pSrcInfo
 ;      Pointer to a D3DXIMAGE_INFO structure to be filled in with the
 ;      description of the data in the source image file, or NULL.
 ;  pPalette
 ;      256 color palette to be filled in, or NULL
 ;  ppTexture, ppCubeTexture, ppVolumeTexture
 ;      The texture object that will be created
 ;
 ;----------------------------------------------------------------------------
 ; FromFile
;API
D3DXCreateTextureFromFileA PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateTextureFromFileW PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateTextureFromFile	equ	<D3DXCreateTextureFromFileW>
ELSE
D3DXCreateTextureFromFile	equ	<D3DXCreateTextureFromFileA>
ENDIF 
;API
D3DXCreateCubeTextureFromFileA PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromFileW PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateCubeTextureFromFile	equ	<D3DXCreateCubeTextureFromFileW>
ELSE
D3DXCreateCubeTextureFromFile	equ	<D3DXCreateCubeTextureFromFileA>
ENDIF 
;API
D3DXCreateVolumeTextureFromFileA PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromFileW PROTO :DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateVolumeTextureFromFile	equ	<D3DXCreateVolumeTextureFromFileW>
ELSE
D3DXCreateVolumeTextureFromFile	equ	<D3DXCreateVolumeTextureFromFileA>
ENDIF 
 ; FromResource
;API
D3DXCreateTextureFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateTextureFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateTextureFromResource	equ	<D3DXCreateTextureFromResourceW>
ELSE
D3DXCreateTextureFromResource	equ	<D3DXCreateTextureFromResourceA>
ENDIF 
;API
D3DXCreateCubeTextureFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateCubeTextureFromResource	equ	<D3DXCreateCubeTextureFromResourceW>
ELSE
D3DXCreateCubeTextureFromResource	equ	<D3DXCreateCubeTextureFromResourceA>
ENDIF 
;API
D3DXCreateVolumeTextureFromResourceA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromResourceW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateVolumeTextureFromResource	equ	<D3DXCreateVolumeTextureFromResourceW>
ELSE
D3DXCreateVolumeTextureFromResource	equ	<D3DXCreateVolumeTextureFromResourceA>
ENDIF 
 ; FromFileEx
;API
D3DXCreateTextureFromFileExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateTextureFromFileExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateTextureFromFileEx	equ	<D3DXCreateTextureFromFileExW>
ELSE
D3DXCreateTextureFromFileEx	equ	<D3DXCreateTextureFromFileExA>
ENDIF 
;API
D3DXCreateCubeTextureFromFileExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromFileExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateCubeTextureFromFileEx	equ	<D3DXCreateCubeTextureFromFileExW>
ELSE
D3DXCreateCubeTextureFromFileEx	equ	<D3DXCreateCubeTextureFromFileExA>
ENDIF 
;API
D3DXCreateVolumeTextureFromFileExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromFileExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateVolumeTextureFromFileEx	equ	<D3DXCreateVolumeTextureFromFileExW>
ELSE
D3DXCreateVolumeTextureFromFileEx	equ	<D3DXCreateVolumeTextureFromFileExA>
ENDIF 
 ; FromResourceEx
;API
D3DXCreateTextureFromResourceExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateTextureFromResourceExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateTextureFromResourceEx	equ	<D3DXCreateTextureFromResourceExW>
ELSE
D3DXCreateTextureFromResourceEx	equ	<D3DXCreateTextureFromResourceExA>
ENDIF 
;API
D3DXCreateCubeTextureFromResourceExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromResourceExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateCubeTextureFromResourceEx	equ	<D3DXCreateCubeTextureFromResourceExW>
ELSE
D3DXCreateCubeTextureFromResourceEx	equ	<D3DXCreateCubeTextureFromResourceExA>
ENDIF 
;API
D3DXCreateVolumeTextureFromResourceExA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromResourceExW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXCreateVolumeTextureFromResourceEx	equ	<D3DXCreateVolumeTextureFromResourceExW>
ELSE
D3DXCreateVolumeTextureFromResourceEx	equ	<D3DXCreateVolumeTextureFromResourceExA>
ENDIF 
 ; FromFileInMemory
;API
D3DXCreateTextureFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromFileInMemory PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
 ; FromFileInMemoryEx
;API
D3DXCreateTextureFromFileInMemoryEx PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateCubeTextureFromFileInMemoryEx PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXCreateVolumeTextureFromFileInMemoryEx PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXSaveTextureToFile:
 ; ----------------------
 ; Save a texture to a file.
 ;
 ; Parameters:
 ;  pDestFile
 ;      File name of the destination file
 ;  DestFormat
 ;      D3DXIMAGE_FILEFORMAT specifying file format to use when saving.
 ;  pSrcTexture
 ;      Source texture, containing the image to be saved
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;
 ;----------------------------------------------------------------------------
;API
D3DXSaveTextureToFileA PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXSaveTextureToFileW PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF UNICODE
D3DXSaveTextureToFile	equ	<D3DXSaveTextureToFileW>
ELSE
D3DXSaveTextureToFile	equ	<D3DXSaveTextureToFileA>
ENDIF 
 ;////////////////////////////////////////////////////////////////////////////
 ; Misc Texture APIs /////////////////////////////////////////////////////////
 ;////////////////////////////////////////////////////////////////////////////
 ;----------------------------------------------------------------------------
 ; D3DXFilterTexture:
 ; ------------------
 ; Filters mipmaps levels of a texture.
 ;
 ; Parameters:
 ;  pBaseTexture
 ;      The texture object to be filtered
 ;  pPalette
 ;      256 color palette to be used, or NULL for non-palettized formats
 ;  SrcLevel
 ;      The level whose image is used to generate the subsequent levels.
 ;  Filter
 ;      D3DX_FILTER flags controlling how each miplevel is filtered.
 ;      Or D3DX_DEFAULT for D3DX_FILTER_BOX,
 ;
 ;----------------------------------------------------------------------------
;API
D3DXFilterTexture PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
D3DXFilterCubeTexture	equ	<D3DXFilterTexture>
D3DXFilterVolumeTexture	equ	<D3DXFilterTexture>
 ;----------------------------------------------------------------------------
 ; D3DXFillTexture:
 ; ----------------
 ; Uses a user provided function to fill each texel of each mip level of a
 ; given texture.
 ;
 ; Paramters:
 ;  pTexture, pCubeTexture, pVolumeTexture
 ;      Pointer to the texture to be filled.
 ;  pFunction
 ;      Pointer to user provided evalutor function which will be used to
 ;      compute the value of each texel.
 ;  pData
 ;      Pointer to an arbitrary block of user defined data.  This pointer
 ;      will be passed to the function provided in pFunction
 ;-----------------------------------------------------------------------------
;API
D3DXFillTexture PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXFillCubeTexture PROTO :DWORD ,:DWORD ,:DWORD 
;API
D3DXFillVolumeTexture PROTO :DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXFillTextureTX:
 ; ----------------
 ; Uses a TX Shader target to function to fill each texel of each mip level of a
 ; given texture. The TX Shader target should be a compiled function taking 2
 ; 2 paramters and returning a float4 color.
 ;
 ; Paramters:
 ;  pTexture, pCubeTexture, pVolumeTexture
 ;      Pointer to the texture to be filled.
 ;  pFunction:
 ;      Pointer to the compiled function returned by D3DX
 ;  pConstants
 ;      Constants used by program. Should be filled by user by parsing constant
 ;      Table information
 ;  Constants
 ;      Number of Constants
 ;-----------------------------------------------------------------------------
;API
D3DXFillTextureTX PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXFillCubeTextureTX PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
;API
D3DXFillVolumeTextureTX PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD 
 ;----------------------------------------------------------------------------
 ; D3DXComputeNormalMap:
 ; ---------------------
 ; Converts a height map into a normal map.  The (x,y,z) components of each
 ; normal are mapped to the (r,g,b) channels of the output texture.
 ;
 ; Parameters
 ;  pTexture
 ;      Pointer to the destination texture
 ;  pSrcTexture
 ;      Pointer to the source heightmap texture
 ;  pSrcPalette
 ;      Source palette of 256 colors, or NULL
 ;  Flags
 ;      D3DX_NORMALMAP flags
 ;  Channel
 ;      D3DX_CHANNEL specifying source of height information
 ;  Amplitude
 ;      The constant value which the height information is multiplied by.
 ;---------------------------------------------------------------------------
;API
D3DXComputeNormalMap PROTO :DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD ,:DWORD 
IFDEF __cplusplus
ENDIF  ;__cplusplus
ENDIF  ;__D3DX9TEX_H__
